import { MintingProps, PromoCodeMode, ShareLinks } from "./Minting.types";
import React, { FC } from 'react'
import { OrderStage, useOrder, OrderProvider } from "../api/OrderContext";
import { AwaitingOrderApproval } from './stages/AwaitingOrderApproval'
import { OrderApproved, OrderApprovedProps } from './stages/OrderApproved'
import { OrderRejected } from './stages/OrderRejected'
import { PlaceOrder, PlaceOrderProps } from './stages/PlaceOrder'
import DinoLabsLogo from './Logo.svg'

const MintingOrder = ({ promoCodeMode, maxAssetsPerOrder, tokenName, onPayClick, termsOfServiceLink, shareLinks }: PlaceOrderProps & OrderApprovedProps) => {
    const { orderStage } = useOrder()
    switch (orderStage) {
        case OrderStage.New: return <PlaceOrder promoCodeMode={promoCodeMode} maxAssetsPerOrder={maxAssetsPerOrder} tokenName={tokenName} termsOfServiceLink={termsOfServiceLink} />
        case OrderStage.Placed: return <AwaitingOrderApproval tokenName={tokenName} />
        case OrderStage.Approved: return <OrderApproved tokenName={tokenName} onPayClick={onPayClick} shareLinks={shareLinks} />
        case OrderStage.Rejected: return <OrderRejected />
        default: throw Error('Unknown state')
    }
}

export const Minting: FC<MintingProps> = ({ collectionId, environment = 'production', ...props }) => {
    return (
        <div className="minting-wizard">
            <OrderProvider collectionId={collectionId} environment={environment}>
                <MintingOrder {...props} />
            </OrderProvider>
            <div className="powered-by-dino">
                Minting powered by <a href="https://www.cryptodino.io/dinolabs" style={{ color: 'inherit' }}><DinoLabsLogo height="30" width="60" viewBox="0 0 800 400" /></a>
            </div>
        </div>
    )
}